
# THIS FILE IS GENERATED FROM SCIPY SETUP.PY
short_version = '0.1.5'
version = '0.1.5'
full_version = '0.1.5.dev1558626070'
dev_version = '1558626070'
release = False
if not release:
    version = full_version
